@@ -7,13 +7,17 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "kconfigbasedkeyfilter.h"
 
 #include <KConfigBase>
 #include <KConfigGroup>
 
-#include <algorithm>
 #include <QDebug>
+#include <QRegularExpression>
+
+#include <algorithm>
 
 using namespace Kleo;
 using namespace GpgME;
@@ -38,13 +42,9 @@ KeyFilter::FontDescription::FontDescription()
 KeyFilter::FontDescription::FontDescription(const FontDescription &other)
     : d(new Private(*other.d))
 {
-
 }
 
-KeyFilter::FontDescription::~FontDescription()
-{
-    delete d;
-}
+KeyFilter::FontDescription::~FontDescription() = default;
 
 KeyFilter::FontDescription KeyFilter::FontDescription::create(bool b, bool i, bool s)
 {
@@ -105,29 +105,33 @@ static const struct {
     Key::OwnerTrust trust;
     UserID::Validity validity;
 } ownerTrustAndValidityMap[] = {
-    { "unknown",   Key::Unknown,   UserID::Unknown   },
-    { "undefined", Key::Undefined, UserID::Undefined },
-    { "never",     Key::Never,     UserID::Never     },
-    { "marginal",  Key::Marginal,  UserID::Marginal  },
-    { "full",      Key::Full,      UserID::Full      },
-    { "ultimate",  Key::Ultimate,  UserID::Ultimate  },
+    // clang-format off
+    {"unknown",   Key::Unknown,   UserID::Unknown  },
+    {"undefined", Key::Undefined, UserID::Undefined},
+    {"never",     Key::Never,     UserID::Never    },
+    {"marginal",  Key::Marginal,  UserID::Marginal },
+    {"full",      Key::Full,      UserID::Full     },
+    {"ultimate",  Key::Ultimate,  UserID::Ultimate },
+    // clang-format on
 };
 
 static Key::OwnerTrust map2OwnerTrust(const QString &s)
 {
-    for (unsigned int i = 0; i < sizeof ownerTrustAndValidityMap / sizeof * ownerTrustAndValidityMap; ++i)
+    for (unsigned int i = 0; i < sizeof ownerTrustAndValidityMap / sizeof *ownerTrustAndValidityMap; ++i) {
         if (s.toLower() == QLatin1String(ownerTrustAndValidityMap[i].name)) {
             return ownerTrustAndValidityMap[i].trust;
         }
+    }
     return ownerTrustAndValidityMap[0].trust;
 }
 
 static UserID::Validity map2Validity(const QString &s)
 {
-    for (unsigned int i = 0; i < sizeof ownerTrustAndValidityMap / sizeof * ownerTrustAndValidityMap; ++i)
+    for (unsigned int i = 0; i < sizeof ownerTrustAndValidityMap / sizeof *ownerTrustAndValidityMap; ++i) {
         if (s.toLower() == QLatin1String(ownerTrustAndValidityMap[i].name)) {
             return ownerTrustAndValidityMap[i].validity;
         }
+    }
     return ownerTrustAndValidityMap[0].validity;
 }
 
@@ -151,10 +155,10 @@ KConfigBasedKeyFilter::KConfigBasedKeyFilter(const KConfigGroup &config)
 #ifdef SET
 #undef SET
 #endif
-#define SET(member,key) \
-    if ( config.hasKey( key ) ) { \
-        set##member(config.readEntry( key, false ) ? Set : NotSet); \
-        setSpecificity(specificity() + 1); \
+#define SET(member, key)                                                                                                                                       \
+    if (config.hasKey(key)) {                                                                                                                                  \
+        set##member(config.readEntry(key, false) ? Set : NotSet);                                                                                              \
+        setSpecificity(specificity() + 1);                                                                                                                     \
     }
     SET(Revoked, "is-revoked");
     SET(Expired, "is-expired");
@@ -175,12 +179,12 @@ KConfigBasedKeyFilter::KConfigBasedKeyFilter(const KConfigGroup &config)
         const char *prefix;
         LevelState state;
     } prefixMap[] = {
-        { "is-", Is },
-        { "is-not-", IsNot },
-        { "is-at-least-", IsAtLeast },
-        { "is-at-most-", IsAtMost },
+        {"is-", Is},
+        {"is-not-", IsNot},
+        {"is-at-least-", IsAtLeast},
+        {"is-at-most-", IsAtMost},
     };
-    for (unsigned int i = 0; i < sizeof prefixMap / sizeof * prefixMap; ++i) {
+    for (unsigned int i = 0; i < sizeof prefixMap / sizeof *prefixMap; ++i) {
         const QString key = QLatin1String(prefixMap[i].prefix) + QLatin1String("ownertrust");
         if (config.hasKey(key)) {
             setOwnerTrust(prefixMap[i].state);
@@ -189,7 +193,7 @@ KConfigBasedKeyFilter::KConfigBasedKeyFilter(const KConfigGroup &config)
             break;
         }
     }
-    for (unsigned int i = 0; i < sizeof prefixMap / sizeof * prefixMap; ++i) {
+    for (unsigned int i = 0; i < sizeof prefixMap / sizeof *prefixMap; ++i) {
         const QString key = QLatin1String(prefixMap[i].prefix) + QLatin1String("validity");
         if (config.hasKey(key)) {
             setValidity(prefixMap[i].state);
@@ -202,15 +206,16 @@ KConfigBasedKeyFilter::KConfigBasedKeyFilter(const KConfigGroup &config)
         const char *key;
         MatchContext context;
     } matchMap[] = {
-        { "any", AnyMatchContext },
-        { "appearance", Appearance },
-        { "filtering", Filtering },
+        {"any", AnyMatchContext},
+        {"appearance", Appearance},
+        {"filtering", Filtering},
     };
-    const QStringList contexts = config.readEntry("match-contexts", "any").toLower().split(QRegExp(QLatin1String("[^a-zA-Z0-9_-!]+")), Qt::SkipEmptyParts);
+    static const QRegularExpression reg(QRegularExpression(QLatin1String("[^a-zA-Z0-9_-!]+")));
+    const QStringList contexts = config.readEntry("match-contexts", "any").toLower().split(reg, Qt::SkipEmptyParts);
     setMatchContexts(NoMatchContext);
-    for (const QString & ctx : contexts) {
+    for (const QString &ctx : contexts) {
         bool found = false;
-        for (unsigned int i = 0; i < sizeof matchMap / sizeof * matchMap; ++i)
+        for (unsigned int i = 0; i < sizeof matchMap / sizeof *matchMap; ++i) {
             if (ctx == QLatin1String(matchMap[i].key)) {
                 setMatchContexts(availableMatchContexts() |= matchMap[i].context);
                 found = true;
@@ -220,13 +225,16 @@ KConfigBasedKeyFilter::KConfigBasedKeyFilter(const KConfigGroup &config)
                 found = true;
                 break;
             }
+        }
         if (!found) {
             qWarning() << QStringLiteral("KConfigBasedKeyFilter: found unknown match context '%1' in group '%2'").arg(ctx, config.name());
         }
     }
     if (availableMatchContexts() == NoMatchContext) {
-        qWarning() << QStringLiteral("KConfigBasedKeyFilter: match context in group '%1' evaluates to NoMatchContext, "
-                                     "replaced by AnyMatchContext").arg(config.name());
+        qWarning() << QStringLiteral(
+                          "KConfigBasedKeyFilter: match context in group '%1' evaluates to NoMatchContext, "
+                          "replaced by AnyMatchContext")
+                          .arg(config.name());
         setMatchContexts(AnyMatchContext);
     }
 }
