@@ -7,52 +7,55 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "cryptoconfigmodule.h"
-#include "cryptoconfigmodule_p.h"
+
 #include "cryptoconfigentryreaderport_p.h"
+#include "cryptoconfigmodule_p.h"
 #include "directoryserviceswidget.h"
-#include "kdhorizontalline.h"
 #include "filenamerequester.h"
 
-#include "kleo/keyserverconfig.h"
-#include "utils/gnupg.h"
+#include <libkleo/formatting.h>
+#include <libkleo/gnupg.h>
+#include <libkleo/keyserverconfig.h>
 
-#include <qgpgme/cryptoconfig.h>
+#include <kleo_ui_debug.h>
 
+#include <KLazyLocalizedString>
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include "kleo_ui_debug.h"
-#include <utils/formatting.h>
-#include <QIcon>
+#include <KSeparator>
+
+#include <QGpgME/CryptoConfig>
+
+#include <QCheckBox>
+#include <QComboBox>
 #include <QDialogButtonBox>
-
-#include <QSpinBox>
-
-#include <QApplication>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QIcon>
 #include <QLabel>
 #include <QLayout>
 #include <QPushButton>
 #include <QRegExp>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QGridLayout>
+#include <QRegularExpression>
+#include <QScreen>
 #include <QScrollArea>
-#include <QDesktopWidget>
-#include <QCheckBox>
+#include <QSpinBox>
 #include <QStyle>
-#include <QComboBox>
-#include <QGroupBox>
+#include <QVBoxLayout>
+#include <QWindow>
 
 #include <gpgme.h>
 
-#include <memory>
-#include <limits>
 #include <array>
+#include <limits>
+#include <memory>
 #include <set>
 
-#include <KLazyLocalizedString>
-
 using namespace Kleo;
 
 namespace
@@ -61,7 +64,10 @@ namespace
 class ScrollArea : public QScrollArea
 {
 public:
-    explicit ScrollArea(QWidget *p) : QScrollArea(p) {}
+    explicit ScrollArea(QWidget *p)
+        : QScrollArea(p)
+    {
+    }
     QSize sizeHint() const override
     {
         const QSize wsz = widget() ? widget()->sizeHint() : QSize();
@@ -73,7 +79,8 @@ public:
 inline QIcon loadIcon(const QString &s)
 {
     QString ss = s;
-    return QIcon::fromTheme(ss.replace(QRegExp(QLatin1String("[^a-zA-Z0-9_]")), QStringLiteral("-")));
+    const static QRegularExpression reg(QRegularExpression(QLatin1String("[^a-zA-Z0-9_]")));
+    return QIcon::fromTheme(ss.replace(reg, QStringLiteral("-")));
 }
 
 static unsigned int num_components_with_options(const QGpgME::CryptoConfig *config)
@@ -100,20 +107,28 @@ static KPageView::FaceType determineJanusFace(const QGpgME::CryptoConfig *config
         ok = false;
         return KPageView::Plain;
     }
-    return
-        layout == CryptoConfigModule::LinearizedLayout ? KPageView::Plain :
-        layout == CryptoConfigModule::TabbedLayout     ? KPageView::Tabbed :
-        /* else */                                       KPageView::List;
+    switch (layout) {
+    case CryptoConfigModule::LinearizedLayout:
+        return KPageView::Plain;
+    case CryptoConfigModule::TabbedLayout:
+        return KPageView::Tabbed;
+    case CryptoConfigModule::IconListLayout:
+        return KPageView::List;
+    }
+    Q_ASSERT(!"we should never get here");
+    return KPageView::List;
 }
 
 Kleo::CryptoConfigModule::CryptoConfigModule(QGpgME::CryptoConfig *config, QWidget *parent)
-    : KPageWidget(parent), mConfig(config)
+    : KPageWidget(parent)
+    , mConfig(config)
 {
     init(IconListLayout);
 }
 
 Kleo::CryptoConfigModule::CryptoConfigModule(QGpgME::CryptoConfig *config, Layout layout, QWidget *parent)
-    : KPageWidget(parent), mConfig(config)
+    : KPageWidget(parent)
+    , mConfig(config)
 {
     init(layout);
 }
@@ -152,7 +167,7 @@ void Kleo::CryptoConfigModule::init(Layout layout)
 
     const QStringList components = sortComponentList(config->componentList());
     for (QStringList::const_iterator it = components.begin(); it != components.end(); ++it) {
-        //qCDebug(KLEO_UI_LOG) <<"Component" << (*it).toLocal8Bit() <<":";
+        // qCDebug(KLEO_UI_LOG) <<"Component" << (*it).toLocal8Bit() <<":";
         QGpgME::CryptoConfigComponent *comp = config->component(*it);
         Q_ASSERT(comp);
         if (comp->groupList().empty()) {
@@ -187,7 +202,7 @@ void Kleo::CryptoConfigModule::init(Layout layout)
             scrollArea->setWidget(compGUI.release());
 
             // Set a nice startup size
-            const int deskHeight = QApplication::desktop()->height();
+            const int deskHeight = screen()->size().height();
             int dialogHeight;
             if (deskHeight > 1000) { // very big desktop ?
                 dialogHeight = 800;
@@ -203,12 +218,13 @@ void Kleo::CryptoConfigModule::init(Layout layout)
         }
     }
     if (mComponentGUIs.empty()) {
-        const QString msg = i18n("The gpgconf tool used to provide the information "
-                                 "for this dialog does not seem to be installed "
-                                 "properly. It did not return any components. "
-                                 "Try running \"%1\" on the command line for more "
-                                 "information.",
-                                 components.empty() ? QLatin1String("gpgconf --list-components") : QLatin1String("gpgconf --list-options gpg"));
+        const QString msg = i18n(
+            "The gpgconf tool used to provide the information "
+            "for this dialog does not seem to be installed "
+            "properly. It did not return any components. "
+            "Try running \"%1\" on the command line for more "
+            "information.",
+            components.empty() ? QLatin1String("gpgconf --list-components") : QLatin1String("gpgconf --list-options gpg"));
         QLabel *label = new QLabel(msg, vbox);
         label->setWordWrap(true);
         label->setMinimumHeight(fontMetrics().lineSpacing() * 5);
@@ -250,7 +266,7 @@ QStringList Kleo::CryptoConfigModule::sortComponentList(const QStringList &compo
         QStringLiteral("gpg-agent"),
         QStringLiteral("dirmngr"),
         QStringLiteral("pinentry"),
-        QStringLiteral("scdaemon")
+        QStringLiteral("scdaemon"),
     };
     return sortConfigEntries(order.begin(), order.end(), components);
 }
@@ -364,8 +380,7 @@ bool offerEntryForConfiguration(QGpgME::CryptoConfigEntry *entry)
     if (entriesToExclude.empty()) {
         entriesToExclude.insert(QStringLiteral("gpg/keyserver"));
         if (engineIsVersion(2, 3, 5, GpgME::GpgConfEngine)
-            || (engineIsVersion(2, 2, 34, GpgME::GpgConfEngine)
-                && !engineIsVersion(2, 3, 0, GpgME::GpgConfEngine))) {
+            || (engineIsVersion(2, 2, 34, GpgME::GpgConfEngine) && !engineIsVersion(2, 3, 0, GpgME::GpgConfEngine))) {
             // exclude for 2.2.{34,...} and 2.3.5+
             entriesToExclude.insert(QStringLiteral("gpgsm/keyserver"));
         }
@@ -374,18 +389,16 @@ bool offerEntryForConfiguration(QGpgME::CryptoConfigEntry *entry)
     const bool de_vs = Kleo::gnupgUsesDeVsCompliance();
     // Skip "dangerous" expert options if we are running in CO_DE_VS.
     // Otherwise, skip any options beyond "invisible" (== expert + 1) level.
-    const auto maxEntryLevel = de_vs ? QGpgME::CryptoConfigEntry::Level_Advanced
+    const auto maxEntryLevel = de_vs ? QGpgME::CryptoConfigEntry::Level_Advanced //
                                      : QGpgME::CryptoConfigEntry::Level_Expert + 1;
     // we ignore the group when looking up entries to exclude because entries
     // are uniquely identified by their name and their component
     const auto entryId = entry->path().replace(entryPathGroupSegmentRegexp, QLatin1String{"/"}).toLower();
-    return (entry->level() <= maxEntryLevel) &&
-           (entriesToExclude.find(entryId) == entriesToExclude.end());
+    return (entry->level() <= maxEntryLevel) && (entriesToExclude.find(entryId) == entriesToExclude.end());
 }
 
 auto getGroupEntriesToOfferForConfiguration(QGpgME::CryptoConfigGroup *group)
 {
-
     std::vector<QGpgME::CryptoConfigEntry *> result;
     const auto entryNames = group->entryList();
     for (const auto &entryName : entryNames) {
@@ -401,16 +414,14 @@ auto getGroupEntriesToOfferForConfiguration(QGpgME::CryptoConfigGroup *group)
 }
 }
 
-Kleo::CryptoConfigComponentGUI::CryptoConfigComponentGUI(
-    CryptoConfigModule *module, QGpgME::CryptoConfigComponent *component,
-    QWidget *parent)
-    : QWidget(parent),
-      mComponent(component)
+Kleo::CryptoConfigComponentGUI::CryptoConfigComponentGUI(CryptoConfigModule *module, QGpgME::CryptoConfigComponent *component, QWidget *parent)
+    : QWidget(parent)
+    , mComponent(component)
 {
     auto glay = new QGridLayout(this);
     const QStringList groups = module->sortGroupList(mComponent->name(), mComponent->groupList());
     if (groups.size() > 1) {
-        glay->setColumnMinimumWidth(0, KDHorizontalLine::indentHint());
+        glay->setColumnMinimumWidth(0, 30);
         for (QStringList::const_iterator it = groups.begin(), end = groups.end(); it != end; ++it) {
             QGpgME::CryptoConfigGroup *group = mComponent->group(*it);
             Q_ASSERT(group);
@@ -423,9 +434,11 @@ Kleo::CryptoConfigComponentGUI::CryptoConfigComponentGUI(
                 continue;
             }
             const QString title = group->description();
-            auto hl = new KDHorizontalLine(title.isEmpty() ? *it : title, this);
+            auto hbox = new QHBoxLayout;
+            hbox->addWidget(new QLabel{title.isEmpty() ? *it : title, this});
+            hbox->addWidget(new KSeparator{Qt::Horizontal, this}, 1);
             const int row = glay->rowCount();
-            glay->addWidget(hl, row, 0, 1, 3);
+            glay->addLayout(hbox, row, 0, 1, 3);
             mGroupGUIs.append(new CryptoConfigGroupGUI(module, group, groupEntries, glay, this));
         }
     } else if (!groups.empty()) {
@@ -468,18 +481,16 @@ void Kleo::CryptoConfigComponentGUI::defaults()
 
 ////
 
-Kleo::CryptoConfigGroupGUI::CryptoConfigGroupGUI(
-        CryptoConfigModule *module,
-        QGpgME::CryptoConfigGroup *group,
-        const std::vector<QGpgME::CryptoConfigEntry *> &entries,
-        QGridLayout *glay,
-        QWidget *widget)
+Kleo::CryptoConfigGroupGUI::CryptoConfigGroupGUI(CryptoConfigModule *module,
+                                                 QGpgME::CryptoConfigGroup *group,
+                                                 const std::vector<QGpgME::CryptoConfigEntry *> &entries,
+                                                 QGridLayout *glay,
+                                                 QWidget *widget)
     : QObject(module)
 {
     const int startRow = glay->rowCount();
     for (auto entry : entries) {
-        CryptoConfigEntryGUI *entryGUI =
-            CryptoConfigEntryGUIFactory::createEntryGUI(module, entry, entry->name(), glay, widget);
+        CryptoConfigEntryGUI *entryGUI = CryptoConfigEntryGUIFactory::createEntryGUI(module, entry, entry->name(), glay, widget);
         if (entryGUI) {
             mEntryGUIs.append(entryGUI);
             entryGUI->load();
@@ -535,7 +546,7 @@ using constructor = CryptoConfigEntryGUI *(*)(CryptoConfigModule *, QGpgME::Cryp
 
 namespace
 {
-template <typename T_Widget>
+template<typename T_Widget>
 CryptoConfigEntryGUI *_create(CryptoConfigModule *m, QGpgME::CryptoConfigEntry *e, const QString &n, QGridLayout *l, QWidget *p)
 {
     return new T_Widget(m, e, n, l, p);
@@ -546,10 +557,10 @@ static const struct WidgetsByEntryName {
     const char *entryGlob;
     constructor create;
 } widgetsByEntryName[] = {
-    { "*/*/debug-level",   &_create<CryptoConfigEntryDebugLevel> },
-    { "scdaemon/*/reader-port", &_create<CryptoConfigEntryReaderPort> },
+    {"*/*/debug-level", &_create<CryptoConfigEntryDebugLevel>},
+    {"scdaemon/*/reader-port", &_create<CryptoConfigEntryReaderPort>},
 };
-static const unsigned int numWidgetsByEntryName = sizeof widgetsByEntryName / sizeof * widgetsByEntryName;
+static const unsigned int numWidgetsByEntryName = sizeof widgetsByEntryName / sizeof *widgetsByEntryName;
 
 static const constructor listWidgets[QGpgME::CryptoConfigEntry::NumArgType] = {
     // None: A list of options with no arguments (e.g. -v -v -v) is shown as a spinbox
@@ -565,17 +576,23 @@ static const constructor listWidgets[QGpgME::CryptoConfigEntry::NumArgType] = {
 };
 
 static const constructor scalarWidgets[QGpgME::CryptoConfigEntry::NumArgType] = {
+    // clang-format off
     &_create<CryptoConfigEntryCheckBox>, // None
     &_create<CryptoConfigEntryLineEdit>, // String
     &_create<CryptoConfigEntrySpinBox>,  // Int
     &_create<CryptoConfigEntrySpinBox>,  // UInt
     &_create<CryptoConfigEntryPath>,     // Path
-    nullptr,                                   // Formerly URL
-    nullptr,                                   // LDAPURL
+    nullptr,                             // Formerly URL
+    nullptr,                             // LDAPURL
     &_create<CryptoConfigEntryDirPath>,  // DirPath
+    // clang-format on
 };
 
-CryptoConfigEntryGUI *Kleo::CryptoConfigEntryGUIFactory::createEntryGUI(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry, const QString &entryName, QGridLayout *glay, QWidget *widget)
+CryptoConfigEntryGUI *Kleo::CryptoConfigEntryGUIFactory::createEntryGUI(CryptoConfigModule *module,
+                                                                        QGpgME::CryptoConfigEntry *entry,
+                                                                        const QString &entryName,
+                                                                        QGridLayout *glay,
+                                                                        QWidget *widget)
 {
     Q_ASSERT(entry);
 
@@ -607,11 +624,11 @@ CryptoConfigEntryGUI *Kleo::CryptoConfigEntryGUIFactory::createEntryGUI(CryptoCo
 
 ////
 
-Kleo::CryptoConfigEntryGUI::CryptoConfigEntryGUI(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry,
-    const QString &entryName)
-    : QObject(module), mEntry(entry), mName(entryName), mChanged(false)
+Kleo::CryptoConfigEntryGUI::CryptoConfigEntryGUI(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry, const QString &entryName)
+    : QObject(module)
+    , mEntry(entry)
+    , mName(entryName)
+    , mChanged(false)
 {
     connect(this, &CryptoConfigEntryGUI::changed, module, &CryptoConfigModule::changed);
 }
@@ -630,7 +647,9 @@ QString Kleo::CryptoConfigEntryGUI::description() const
               "Context: We get some backend strings in that have the wrong "
               "capitalization (in English, at least) so we need to force the "
               "first character to upper-case. It is this behaviour you can "
-              "control for your language with this translation.", "yes") == QLatin1String("yes")) {
+              "control for your language with this translation.",
+              "yes")
+        == QLatin1String("yes")) {
         descr[0] = descr[0].toUpper();
     }
     return descr;
@@ -644,10 +663,11 @@ void Kleo::CryptoConfigEntryGUI::resetToDefault()
 
 ////
 
-Kleo::CryptoConfigEntryLineEdit::CryptoConfigEntryLineEdit(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
+Kleo::CryptoConfigEntryLineEdit::CryptoConfigEntryLineEdit(CryptoConfigModule *module,
+                                                           QGpgME::CryptoConfigEntry *entry,
+                                                           const QString &entryName,
+                                                           QGridLayout *glay,
+                                                           QWidget *widget)
     : CryptoConfigEntryGUI(module, entry, entryName)
 {
     const int row = glay->rowCount();
@@ -682,18 +702,21 @@ static const struct {
     const KLazyLocalizedString label;
     const char *name;
 } debugLevels[] = {
-    { kli18n("0 - None"), "none"},
-    { kli18n("1 - Basic"), "basic"},
-    { kli18n("2 - Verbose"), "advanced"},
-    { kli18n("3 - More Verbose"), "expert"},
-    { kli18n("4 - All"), "10"},
+    {kli18n("0 - None"), "none"},
+    {kli18n("1 - Basic"), "basic"},
+    {kli18n("2 - Verbose"), "advanced"},
+    {kli18n("3 - More Verbose"), "expert"},
+    {kli18n("4 - All"), "10"},
 };
-static const unsigned int numDebugLevels = sizeof debugLevels / sizeof * debugLevels;
+static const unsigned int numDebugLevels = sizeof debugLevels / sizeof *debugLevels;
 
-Kleo::CryptoConfigEntryDebugLevel::CryptoConfigEntryDebugLevel(CryptoConfigModule *module, QGpgME::CryptoConfigEntry *entry,
-        const QString &entryName, QGridLayout *glay, QWidget *widget)
-    : CryptoConfigEntryGUI(module, entry, entryName),
-      mComboBox(new QComboBox(widget))
+Kleo::CryptoConfigEntryDebugLevel::CryptoConfigEntryDebugLevel(CryptoConfigModule *module,
+                                                               QGpgME::CryptoConfigEntry *entry,
+                                                               const QString &entryName,
+                                                               QGridLayout *glay,
+                                                               QWidget *widget)
+    : CryptoConfigEntryGUI(module, entry, entryName)
+    , mComboBox(new QComboBox(widget))
 {
     QLabel *label = new QLabel(i18n("Set the debugging level to"), widget);
     label->setBuddy(mComboBox);
@@ -706,8 +729,7 @@ Kleo::CryptoConfigEntryDebugLevel::CryptoConfigEntryDebugLevel(CryptoConfigModul
         label->setEnabled(false);
         mComboBox->setEnabled(false);
     } else {
-        connect(mComboBox, qOverload<int>(&QComboBox::currentIndexChanged),
-                this, &CryptoConfigEntryDebugLevel::slotChanged);
+        connect(mComboBox, qOverload<int>(&QComboBox::currentIndexChanged), this, &CryptoConfigEntryDebugLevel::slotChanged);
     }
 
     const int row = glay->rowCount();
@@ -739,12 +761,13 @@ void Kleo::CryptoConfigEntryDebugLevel::doLoad()
 
 ////
 
-Kleo::CryptoConfigEntryPath::CryptoConfigEntryPath(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
-    : CryptoConfigEntryGUI(module, entry, entryName),
-      mFileNameRequester(nullptr)
+Kleo::CryptoConfigEntryPath::CryptoConfigEntryPath(CryptoConfigModule *module,
+                                                   QGpgME::CryptoConfigEntry *entry,
+                                                   const QString &entryName,
+                                                   QGridLayout *glay,
+                                                   QWidget *widget)
+    : CryptoConfigEntryGUI(module, entry, entryName)
+    , mFileNameRequester(nullptr)
 {
     const int row = glay->rowCount();
     mFileNameRequester = new FileNameRequester(widget);
@@ -778,12 +801,13 @@ void Kleo::CryptoConfigEntryPath::doLoad()
 
 ////
 
-Kleo::CryptoConfigEntryDirPath::CryptoConfigEntryDirPath(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
-    : CryptoConfigEntryGUI(module, entry, entryName),
-      mFileNameRequester(nullptr)
+Kleo::CryptoConfigEntryDirPath::CryptoConfigEntryDirPath(CryptoConfigModule *module,
+                                                         QGpgME::CryptoConfigEntry *entry,
+                                                         const QString &entryName,
+                                                         QGridLayout *glay,
+                                                         QWidget *widget)
+    : CryptoConfigEntryGUI(module, entry, entryName)
+    , mFileNameRequester(nullptr)
 {
     const int row = glay->rowCount();
     mFileNameRequester = new FileNameRequester(widget);
@@ -813,13 +837,13 @@ void Kleo::CryptoConfigEntryDirPath::doLoad()
 
 ////
 
-Kleo::CryptoConfigEntrySpinBox::CryptoConfigEntrySpinBox(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
+Kleo::CryptoConfigEntrySpinBox::CryptoConfigEntrySpinBox(CryptoConfigModule *module,
+                                                         QGpgME::CryptoConfigEntry *entry,
+                                                         const QString &entryName,
+                                                         QGridLayout *glay,
+                                                         QWidget *widget)
     : CryptoConfigEntryGUI(module, entry, entryName)
 {
-
     if (entry->argType() == QGpgME::CryptoConfigEntry::ArgType_None && entry->isList()) {
         mKind = ListOfNone;
     } else if (entry->argType() == QGpgME::CryptoConfigEntry::ArgType_UInt) {
@@ -881,10 +905,11 @@ void Kleo::CryptoConfigEntrySpinBox::doLoad()
 
 ////
 
-Kleo::CryptoConfigEntryCheckBox::CryptoConfigEntryCheckBox(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry, const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
+Kleo::CryptoConfigEntryCheckBox::CryptoConfigEntryCheckBox(CryptoConfigModule *module,
+                                                           QGpgME::CryptoConfigEntry *entry,
+                                                           const QString &entryName,
+                                                           QGridLayout *glay,
+                                                           QWidget *widget)
     : CryptoConfigEntryGUI(module, entry, entryName)
 {
     const int row = glay->rowCount();
@@ -908,11 +933,11 @@ void Kleo::CryptoConfigEntryCheckBox::doLoad()
     mCheckBox->setChecked(mEntry->boolValue());
 }
 
-Kleo::CryptoConfigEntryLDAPURL::CryptoConfigEntryLDAPURL(
-    CryptoConfigModule *module,
-    QGpgME::CryptoConfigEntry *entry,
-    const QString &entryName,
-    QGridLayout *glay, QWidget *widget)
+Kleo::CryptoConfigEntryLDAPURL::CryptoConfigEntryLDAPURL(CryptoConfigModule *module,
+                                                         QGpgME::CryptoConfigEntry *entry,
+                                                         const QString &entryName,
+                                                         QGridLayout *glay,
+                                                         QWidget *widget)
     : CryptoConfigEntryGUI(module, entry, entryName)
 {
     mLabel = new QLabel(widget);
@@ -987,13 +1012,17 @@ void Kleo::CryptoConfigEntryLDAPURL::slotOpenDialog()
     dirserv->setReadOnly(mEntry->isReadOnly());
 
     std::vector<KeyserverConfig> servers;
-    std::transform(std::cbegin(mURLList), std::cend(mURLList), std::back_inserter(servers), [](const auto &url) { return KeyserverConfig::fromUrl(url); });
+    std::transform(std::cbegin(mURLList), std::cend(mURLList), std::back_inserter(servers), [](const auto &url) {
+        return KeyserverConfig::fromUrl(url);
+    });
     dirserv->setKeyservers(servers);
 
     if (dialog.exec()) {
         QList<QUrl> urls;
         const auto servers = dirserv->keyservers();
-        std::transform(std::begin(servers), std::end(servers), std::back_inserter(urls), [](const auto &server) { return server.toUrl(); });
+        std::transform(std::begin(servers), std::end(servers), std::back_inserter(urls), [](const auto &server) {
+            return server.toUrl();
+        });
         setURLList(urls);
         slotChanged();
     }
